@@ -8,7 +8,7 @@ use PICA::Parser::PPXML;
 sub parse {
     my ( $self, $record ) = @_;
 
-    my $xml = $record->{recordData};
+    my $xml = $record->{recordData}->toString();
     my $parser = PICA::Parser::PPXML->new( $xml ); 
 
     return $parser->next;
