@@ -1,10 +1,12 @@
 package Catmandu::PICA;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 1;
 __END__
 
+=encoding utf-8
+
 =head1 NAME
 
 Catmandu::PICA - Catmandu modules for working with PICA+ data
@@ -25,32 +27,38 @@ framework.
 See L<PICA::Data> for more information about PICA data format and record
 structure.
 
-See L<Catmandu::Introduction> and L<http://librecat.org/> for an
+See L<Catmandu::Introduction> and L<http://librecat.org/Catmandu> for an
 introduction into Catmandu.
 
 =head1 CATMANDU MODULES
 
 =over
 
-=item * L<Catmandu::Importer::PICA>
-
 =item * L<Catmandu::Exporter::PICA>
 
-=item * L<Catmandu::Importer::SRU::Parser::picaxml>
+=item * L<Catmandu::Fix::Bind::pica_each>
 
-=item * L<Catmandu::Fix::pica_map>
+=item * L<Catmandu::Fix::Condition::pica_match>
 
 =item * L<Catmandu::Fix::pica_add>
 
+=item * L<Catmandu::Fix::pica_map>
+
 =item * L<Catmandu::Fix::pica_set>
 
+=item * L<Catmandu::Importer::PICA>
+
+=item * L<Catmandu::Importer::SRU::Parser::picaxml>
+
+=item * L<Catmandu::Importer::SRU::Parser::ppxml>
+
+=item * L<Catmandu::Validator::PICA>
+
 =back
 
 =head1 CONTRIBUTORS
 
-=encoding utf8
-
-Johann Rolschewski, <jorol@cpan.org>
+Johann Rolschewski <jorol@cpan.org>
 
 Jakob Voß <voss@gbv.de>
 
@@ -69,4 +77,4 @@ the same terms as Perl itself.
 
 L<PICA::Data>, L<Catmandu>
 
-=cut
+=cut
\ No newline at end of file
